interface CustomTrigger {
    /**
     * Unique ID of the trigger
     * @minLength 1
     * @maxLength 100
     */
    _id?: string;
    /**
     * App ID of the trigger provider
     * @format GUID
     */
    appId?: string;
}
interface GetEligibleTriggersRequest {
    /**
     * List of line items to check the custom triggers on
     * @maxSize 1000
     */
    lineItems?: LineItem[];
    /**
     * List of custom triggers to check 'is eligible' on
     * @minSize 1
     * @maxSize 100
     */
    triggers?: TriggerToFilterBy[];
    /**
     * Persistent ID that correlates between the various eCommerce elements: cart, checkout, and order.
     * @format GUID
     */
    purchaseFlowId?: string | null;
}
interface LineItem {
    /**
     * Line item ID.
     * @minLength 1
     * @maxLength 100
     */
    _id?: string;
    /**
     * Item quantity in this line item.
     * @max 100000
     */
    quantity?: number | null;
    /**
     * Catalog and item reference. Holds IDs for the item and the catalog it came from, as well as further optional info.
     * This field may be empty in the case of a custom line item.
     */
    catalogReference?: CatalogReference;
    /**
     * Price of a single item.
     * @decimalValue options { gte:0 }
     */
    price?: string;
}
/** Used for grouping line items. Sent when an item is added to a cart, checkout, or order. */
interface CatalogReference {
    /**
     * ID of the item within the catalog it belongs to.
     * @minLength 1
     * @maxLength 36
     */
    catalogItemId?: string;
    /**
     * ID of the app providing the catalog.
     *
     * You can get your app's ID from its page in the [app dashboard](https://dev.wix.com/dc3/my-apps/).
     *
     * For items from Wix catalogs, the following values always apply:
     * + Wix Stores: `"215238eb-22a5-4c36-9e7b-e7c08025e04e"`
     * + Wix Bookings: `"13d21c63-b5ec-5912-8397-c3a5ddb27a97"`
     * + Wix Restaurants: `"9a5d83fd-8570-482e-81ab-cfa88942ee60"`
     * @minLength 1
     */
    appId?: string;
    /**
     * Additional item details in key:value pairs. Use this optional field to provide more specificity with item selection. The `options` field values differ depending on which catalog is providing the items.
     *
     * For products and variants from a Wix Stores catalog, learn more about eCommerce integration ([SDK](https://dev.wix.com/docs/sdk/backend-modules/stores/catalog-v3/e-commerce-integration) | [REST](https://dev.wix.com/docs/rest/business-solutions/stores/catalog/e-commerce-integration)).
     */
    options?: Record<string, any> | null;
}
interface TriggerToFilterBy {
    /** Custom trigger */
    customTrigger?: CustomTrigger;
    /**
     * Unique identifier that will return in `EligibleTrigger.identifier` to distinguish between scopes
     * @minLength 1
     * @maxLength 100
     */
    identifier?: string | null;
}
interface GetEligibleTriggersResponse {
    /**
     * A List of eligible custom triggers
     * @maxSize 100
     */
    eligibleTriggers?: EligibleTrigger[];
}
interface EligibleTrigger {
    /**
     * The ID of the custom trigger
     * @minLength 1
     * @maxLength 100
     */
    customTriggerId?: string;
    /**
     * The id of the application implements this custom trigger
     * @format GUID
     */
    appId?: string;
    /**
     * Unique identifier that was assigned in `TriggerToFilterBy.identifier` to distinguish between custom triggers
     * @minLength 1
     * @maxLength 100
     */
    identifier?: string | null;
}
interface ListTriggersRequest {
}
interface ListTriggersResponse {
    /**
     * A list of all custom triggers
     * @maxSize 100
     */
    triggers?: ListTriggersResponseCustomTrigger[];
}
interface ListTriggersResponseCustomTrigger {
    /**
     * Unique ID of the custom trigger
     * @minLength 1
     * @maxLength 100
     */
    _id?: string;
    /**
     * App ID of the custom trigger provider
     * @format GUID
     */
    appId?: string;
    /**
     * Custom Trigger display name
     * @minLength 1
     * @maxLength 200
     */
    name?: string;
}

export type { CustomTrigger as C, EligibleTrigger as E, GetEligibleTriggersRequest as G, ListTriggersResponse as L, TriggerToFilterBy as T, LineItem as a, CatalogReference as b, GetEligibleTriggersResponse as c, ListTriggersRequest as d, ListTriggersResponseCustomTrigger as e };
